@@ -52,6 +52,7 @@ class RpcEndpoint:
     answer_type: Type[Answer]
     exception_type_to_answer_type: dict[Type[Exception], Type[Answer]]
     unhandled_exception__answer_type: Type[Answer] | None = None
+    operation_id: str | None = None
 
     def get_parameters(self) -> set[Parameter]:
         result = set()
@@ -91,7 +92,7 @@ class OpenApiServer:
         self.wrapper = OpenApiWrapper(config, context)
 
     def register_handler(self, method: str, path: str, rpc_endpoint: RpcEndpoint) -> None:
-        operation_id = rpc_endpoint.callable.__name__
+        operation_id = rpc_endpoint.operation_id or rpc_endpoint.callable.__name__
         request_body = None
         body_parameter_type_to_parameters: dict[Type[Parameter], list[Parameter]] = {}
         non_body_parameters = []
